@@ -1,6 +1,7 @@
 import argparse
 import functools
 import os
+import pathlib
 import re
 import sys
 import textwrap
@@ -194,14 +195,25 @@ def _get_base_parser(add_help: bool = True) -> argparse.ArgumentParser:
         required=False,
         default=os.getenv("GITLAB_URL"),
     )
-    parser.add_argument(
+
+    ssl_verify_group = parser.add_mutually_exclusive_group()
+    ssl_verify_group.add_argument(
         "--ssl-verify",
         help=(
-            "Whether SSL certificates should be validated. [env var: GITLAB_SSL_VERIFY]"
+            "Path to a CA_BUNDLE file or directory with certificates of trusted CAs. "
+            "[env var: GITLAB_SSL_VERIFY]"
         ),
         required=False,
         default=os.getenv("GITLAB_SSL_VERIFY"),
     )
+    ssl_verify_group.add_argument(
+        "--no-ssl-verify",
+        help="Disable SSL verification",
+        required=False,
+        dest="ssl_verify",
+        action="store_false",
+    )
+
     parser.add_argument(
         "--timeout",
         help=(
@@ -270,6 +282,16 @@ def _get_base_parser(add_help: bool = True) -> argparse.ArgumentParser:
         help=("GitLab CI job token [env var: CI_JOB_TOKEN]"),
         required=False,
     )
+    parser.add_argument(
+        "--skip-login",
+        help=(
+            "Skip initial authenticated API call to the current user endpoint. "
+            "This may  be useful when invoking the CLI in scripts. "
+            "[env var: GITLAB_SKIP_LOGIN]"
+        ),
+        action="store_true",
+        default=os.getenv("GITLAB_SKIP_LOGIN"),
+    )
     return parser
 
 
@@ -287,12 +309,17 @@ def _parse_value(v: Any) -> Any:
         return v[1:]
     if isinstance(v, str) and v.startswith("@"):
         # If the user-provided value starts with @, we try to read the file
-        # path provided after @ as the real value. Exit on any error.
+        # path provided after @ as the real value.
+        filepath = pathlib.Path(v[1:]).expanduser().resolve()
         try:
-            with open(v[1:], encoding="utf-8") as f:
+            with open(filepath, encoding="utf-8") as f:
                 return f.read()
-        except Exception as e:
-            sys.stderr.write(f"{e}\n")
+        except UnicodeDecodeError:
+            with open(filepath, "rb") as f:
+                return f.read()
+        except OSError as exc:
+            exc_name = type(exc).__name__
+            sys.stderr.write(f"{exc_name}: {exc}\n")
             sys.exit(1)
 
     return v
@@ -351,6 +378,7 @@ def main() -> None:
     debug = args.debug
     gitlab_resource = args.gitlab_resource
     resource_action = args.resource_action
+    skip_login = args.skip_login
 
     args_dict = vars(args)
     # Remove CLI behavior-related args
@@ -373,6 +401,7 @@ def main() -> None:
         "private_token",
         "oauth_token",
         "job_token",
+        "skip_login",
     ):
         args_dict.pop(item)
     args_dict = {k: _parse_value(v) for k, v in args_dict.items() if v is not None}
@@ -381,7 +410,7 @@ def main() -> None:
         gl = gitlab.Gitlab.merge_config(vars(options), gitlab_id, config_files)
         if debug:
             gl.enable_debug()
-        if gl.private_token or gl.oauth_token:
+        if not skip_login and (gl.private_token or gl.oauth_token):
             gl.auth()
     except Exception as e:
         die(str(e))
